@@ -365,7 +365,7 @@ multinom.spls.cv <- function(X, Y, lambda.ridge.range, lambda.l1.range, ncomp.ra
                     stop("Message from multinom.spls.cv: the procedure stops because number of predictor variables with no null variance is less than 1.")
                }
                
-               warning("There are covariables with nul variance")
+               warning("Message from multinom.spls.cv: There are covariables with nul variance in the current sub-sampling, they will be ignored.")
                
                # remove predictor with null variance
                Xtrain <- Xtrain[,which(sigma2train >= .Machine$double.eps)]
