@@ -2,7 +2,7 @@
 ###
 ###     Determination of the number of latent components to be used for Classification with PLS Dimension Reduction and Linear Discriminant Analysis
 ###
-### Copyright 2005-04 Anne-Laure Boulesteix and Korbinian Strimmer
+### Copyright 2004-04 Anne-Laure Boulesteix and Korbinian Strimmer
 ###
 ### 
 ###
@@ -36,7 +36,7 @@ if (length(ncomp)==1)
   ncomp<-1:ncomp
  }
 n<-nrow(Xtrain)
-ntrain<-floor(n*2/3)
+ntrain<-floor(n*alpha)
 samp<-matrix(0,ntrain,nruncv)
 for (i in 1:nruncv)
  {
